==> TkinterExtensions-1.4.33-py3-none-any.whl: TkinterExtensions/Bindings/Bindings.py <==
# ------------------------------------------------------------------------------
#  Created by Tyler Stegmaier
#  Copyright (c) 2020.
#
# ------------------------------------------------------------------------------

from enum import Enum




__all__ = [
        'Bindings'
        # 'Special', 'Mouse', 'UpperCase', 'LowerCase', 'FunctionKeys', 'Custom', 'Core', 'ComboBox', 'ThemedTreeView', 'ListBox', 'Numbers', 'Foucs',
        ]

class Bindings(Enum):
    """ https://www.tcl.tk/man/tcl8.6/TkCmd/event.htm """
    UNKNOWN = '??'

    # class Special(Enum):
    Activate = "<Activate>"
    Configure = "<Configure>"
    Deactivate = "<Deactivate>"
    Destroy = "<Destroy>"
    Expose = "<Expose>"
    Map = "<Map>"
    Motion = "<Motion>"
    MouseWheel = "<MouseWheel>"
    Unmap = "<Unmap>"
    Visibility = "<Visibility>"
    WM_DELETE_WINDOW = "WM_DELETE_WINDOW"

    # class Mouse(Enum):
    B1_Motion = "<B1-Motion>"
    B2_Motion = "<B2-Motion>"
    Button = "<Button>"
    Button1 = "<Button-1>"
    Button2 = "<Button-2>"
    Button3 = "<Button-3>"
    ButtonRelease = "<ButtonRelease>"
    ButtonRelease1 = "<ButtonRelease-1>"
    ButtonRelease2 = "<ButtonRelease-2>"
    ButtonRelease3 = "<ButtonRelease-3>"
    Double_Button = "<Double-Button>"
    Double_Button2 = "<Double-Button-2>"
    Double_Button3 = "<Double-Button-3>"

    # class UpperCase(Enum):
    A = "A"
    B = "B"
    C = "C"
    D = "D"
    E = "E"
    F = "F"
    G = "G"
    H = "H"
    I = "I"
    J = "J"
    K = "K"
    L = "L"
    M = "M"
    N = "N"
    O = "O"
    P = "P"
    Q = "Q"
    R = "R"
    S = "S"
    T = "T"
    U = "U"
    V = "V"
    W = "W"
    X = "X"
    Y = "Y"
    Z = "Z"

    # class LowerCase(Enum):
    a = "a"
    b = "b"
    c = "c"
    d = "d"
    e = "e"
    f = "f"
    g = "g"
    h = "h"
    i = "i"
    j = "j"
    k = "k"
    l = "l"
    m = "m"
    n = "n"
    o = "o"
    p = "p"
    q = "q"
    r = "r"
    s = "s"
    t = "t"
    u = "u"
    v = "v"
    w = "w"
    x = "_x"
    y = "_y"
    z = "z"

    # class Custom(Enum):
    ShiftTab = "ShiftTab",
    ShiftTabEvent = "<Shift-KeyPress-Tab>"

    # class FunctionKeys(Enum):
    F1 = '<F1>'
    F2 = '<F2>'
    F3 = '<F3>'
    F4 = '<F4>'
    F5 = '<F5>'
    F6 = '<F6>'
    F7 = '<F7>'
    F8 = '<F8>'
    F9 = '<F9>'
    F10 = '<F10>'
    F11 = '<F11>'
    F12 = '<F12>'

    # class Foucs(Enum):
    Enter_Boundary = "<Enter>"
    Leave_Boundary = "<Leave>"
    FocusIn = "<FocusIn>"
    FocusOut = "<FocusOut>"
    Prior = "Prior"
    Next = "Next"
    NextWindow = '<<NextWindow>>'
    PrevWindow = '<<PrevWindow>>'

    # class Core(Enum):
    Alt_L = "Alt_L"
    BackSpace = "BackSpace"
    Cancel = "Cancel"
    Caps_Lock = "Caps_Lock"
    Control_L = "Control_L"
    Delete = "Delete"
    Down = "Down"
    End = "End"
    Enter = "Enter"
    Escape = "Escape"
    Home = "Home"
    Insert = "Insert"
    KP_Add = "KP_Add"
    KP_Enter = "KP_Enter"
    KP_Subtract = "KP_Subtract"
    Key = "<Key>"
    Left = "Left"
    Minus = "minus"
    Num_Lock = "Num_Lock"
    Pause = "Pause"
    Plus = "plus"
    Print = "Print"
    Return = "Return"
    Right = "Right"
    Scroll_Lock = "Scroll_Lock"
    Shift = "Shift"
    Shift_Down = "<Shift-Down>"
    Shift_L = "Shift_L"
    Shift_Left = "<Shift-Left>"
    Shift_Right = "<Shift-Right>"
    Shift_Up = "<Shift-Up>"
    Tab = "Tab"
    Up = "Up"

    # class ListBox(Enum):
    ListboxSelect = "<<ListboxSelect>>"

    # class ComboBox(Enum):
    ComboboxSelected = "<<ComboboxSelected>>"

    # class Text(Enum):
    Selection = "<<Selection>>"

    # class Numbers(Enum):
    eight = "8"
    five = "5"
    four = "4"
    nine = "9"
    one = "1"
    seven = "7"
    six = "6"
    three = "3"
    two = "2"
    zero = "0"

    # class ThemedTreeView(Enum):
    TreeViewSelect = "<<TreeviewSelect>>"


    @staticmethod
    def IsEnter(keysym) -> bool:
        if isinstance(keysym, str): keysym = Bindings(keysym)

        return keysym == Bindings.Enter or keysym == Bindings.KP_Enter or keysym == Bindings.Return

==> TkinterExtensions-1.4.39-py3-none-any.whl: TkinterExtensions/Bindings/Bindings.py <==
# ------------------------------------------------------------------------------
#  Created by Tyler Stegmaier
#  Copyright (c) 2020.
#
# ------------------------------------------------------------------------------

from enum import Enum




__all__ = [
        'Bindings'
        # 'Special', 'Mouse', 'UpperCase', 'LowerCase', 'FunctionKeys', 'Custom', 'Core', 'ComboBox', 'ThemedTreeView', 'ListBox', 'Numbers', 'Foucs',
        ]

class Bindings(Enum):
    """ https://www.tcl.tk/man/tcl8.6/TkCmd/event.htm """
    UNKNOWN = '??'

    # class Special(Enum):
    Activate = "<Activate>"
    Configure = "<Configure>"
    Deactivate = "<Deactivate>"
    Destroy = "<Destroy>"
    Expose = "<Expose>"
    Map = "<Map>"
    Motion = "<Motion>"
    MouseWheel = "<MouseWheel>"
    Unmap = "<Unmap>"
    Visibility = "<Visibility>"
    WM_DELETE_WINDOW = "WM_DELETE_WINDOW"

    # class Mouse(Enum):
    B1_Motion = "<B1-Motion>"
    B2_Motion = "<B2-Motion>"
    Button = "<Button>"
    Button1 = "<Button-1>"
    Button2 = "<Button-2>"
    Button3 = "<Button-3>"
    ButtonRelease = "<ButtonRelease>"
    ButtonRelease1 = "<ButtonRelease-1>"
    ButtonRelease2 = "<ButtonRelease-2>"
    ButtonRelease3 = "<ButtonRelease-3>"
    Double_Button = "<Double-Button>"
    Double_Button2 = "<Double-Button-2>"
    Double_Button3 = "<Double-Button-3>"

    # class UpperCase(Enum):
    A = "A"
    B = "B"
    C = "C"
    D = "D"
    E = "E"
    F = "F"
    G = "G"
    H = "H"
    I = "I"
    J = "J"
    K = "K"
    L = "L"
    M = "M"
    N = "N"
    O = "O"
    P = "P"
    Q = "Q"
    R = "R"
    S = "S"
    T = "T"
    U = "U"
    V = "V"
    W = "W"
    X = "X"
    Y = "Y"
    Z = "Z"

    # class LowerCase(Enum):
    a = "a"
    b = "b"
    c = "c"
    d = "d"
    e = "e"
    f = "f"
    g = "g"
    h = "h"
    i = "i"
    j = "j"
    k = "k"
    l = "l"
    m = "m"
    n = "n"
    o = "o"
    p = "p"
    q = "q"
    r = "r"
    s = "s"
    t = "t"
    u = "u"
    v = "v"
    w = "w"
    x = "_x"
    y = "_y"
    z = "z"

    # class Custom(Enum):
    ShiftTab = "Shift_Tab",
    ShiftTabEvent = "<Shift-KeyPress-Tab>"

    # class FunctionKeys(Enum):
    F1 = '<F1>'
    F2 = '<F2>'
    F3 = '<F3>'
    F4 = '<F4>'
    F5 = '<F5>'
    F6 = '<F6>'
    F7 = '<F7>'
    F8 = '<F8>'
    F9 = '<F9>'
    F10 = '<F10>'
    F11 = '<F11>'
    F12 = '<F12>'

    # class Foucs(Enum):
    Enter_Boundary = "<Enter>"
    Leave_Boundary = "<Leave>"
    FocusIn = "<FocusIn>"
    FocusOut = "<FocusOut>"
    Prior = "Prior"
    Next = "Next"
    NextWindow = '<<NextWindow>>'
    PrevWindow = '<<PrevWindow>>'

    # class Core(Enum):
    Alt_L = "Alt_L"
    BackSpace = "BackSpace"
    Cancel = "Cancel"
    Caps_Lock = "Caps_Lock"
    Control_L = "Control_L"
    Delete = "Delete"
    Down = "Down"
    End = "End"
    Enter = "Enter"
    Escape = "Escape"
    Home = "Home"
    Insert = "Insert"
    KP_Add = "KP_Add"
    KP_Enter = "KP_Enter"
    KP_Subtract = "KP_Subtract"
    Key = "<Key>"
    Left = "Left"
    Minus = "minus"
    Num_Lock = "Num_Lock"
    Pause = "Pause"
    Plus = "plus"
    Print = "Print"
    Return = "Return"
    Right = "Right"
    Scroll_Lock = "Scroll_Lock"
    Shift = "Shift"
    Shift_Down = "<Shift-Down>"
    Shift_L = "Shift_L"
    Shift_Left = "<Shift-Left>"
    Shift_Right = "<Shift-Right>"
    Shift_Up = "<Shift-Up>"
    Tab = "Tab"
    Up = "Up"

    # class ListBox(Enum):
    ListboxSelect = "<<ListboxSelect>>"

    # class ComboBox(Enum):
    ComboboxSelected = "<<ComboboxSelected>>"

    # class Text(Enum):
    Selection = "<<Selection>>"

    # class Numbers(Enum):
    eight = "8"
    five = "5"
    four = "4"
    nine = "9"
    one = "1"
    seven = "7"
    six = "6"
    three = "3"
    two = "2"
    zero = "0"

    # class ThemedTreeView(Enum):
    TreeViewSelect = "<<TreeviewSelect>>"


    @staticmethod
    def IsEnter(keysym) -> bool:
        if isinstance(keysym, str): keysym = Bindings(keysym)

        return keysym == Bindings.Enter or keysym == Bindings.KP_Enter or keysym == Bindings.Return
